@@ -529,6 +529,7 @@ class RTMSlackBot(SlackBot):
                  user_member_ids: Union[str, List[str]] = None,
                  token: str = BOT_TOKEN,
                  channel_name: str = None,
+                 channel_id: str = None,
                  auto_reconnect: bool = True,
                  ping_interval: int = 10,
                  alert_level: int = 30,
@@ -544,12 +545,16 @@ class RTMSlackBot(SlackBot):
             a user's profile, click the three dots (...) and there is the member ID. Example of a slack member ID: ABCDEF.
         :param str token: token to connect to slack client
         :param str channel_name: channel to message on. for example, #channelname
+        :param str channel_id: channel id to listen for events on. If set, only events on this channel will be be
+            caught and handled. for example: C1234ABCD. Find more information on finding this here:
+            https://stackoverflow.com/questions/40940327/what-is-the-simplest-way-to-find-a-slack-team-id-and-a-channel-id
         :param auto_reconnect: enable/disable RTM auto-reconnect
         :param ping_interval: ping interval for RTM client
         :param alert_level: alert level to notify the defined user at
         :param formatter: logging formatter to use (if not specified, the class DEFAULT_FORMATTER is used)
         """
         self._temp_client: slack.WebClient = None
+        self._channel_id = channel_id
         self.rtm_client: slack.RTMClient = slack.RTMClient(
             token=token,
             auto_reconnect=auto_reconnect,
@@ -591,6 +596,15 @@ class RTMSlackBot(SlackBot):
     def temporary_web_client(self, value: slack.WebClient):
         self._temp_client = value
 
+    @property
+    def channel_id(self) -> str:
+        """channel id to listen for events on"""
+        return self._channel_id
+
+    @channel_id.setter
+    def channel_id(self, value: str):
+        self._channel_id = value
+
     @temporary_web_client.deleter
     def temporary_web_client(self):
         self._temp_client = None
